BackupFolder class

{n, t, p, c} — name, folder type, parent id (null at top level), children.

Annotations
  • @experimental

Constructors

BackupFolder({String name = '', String type = '', String? parent, List<String> children = const <String>[]})
const
BackupFolder.fromJson(Map<String, dynamic> json)
factory

Properties

children List<String>
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
parent String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited