IconRule class

The icon for a node type (in defaults) or for a single node id (in overrides). variations maps an expression (exp:/state:, see the format spec 9) to the icon name that replaces the base one when true.

Constructors

IconRule({String icon = '', String type = '', Map<String, String> variations = const <String, String>{}, String? path})
const
IconRule.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
icon String
final
path String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
variations Map<String, String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited