SessionNodeMeasures class

Live word/character measures of one node when a session closes.

Constructors

SessionNodeMeasures({required int words, required int characters})
const
SessionNodeMeasures.zero()
const

Properties

characters int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
words int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited