SessionTotal class

Constructors

SessionTotal({String typeTarget = '', int words = 0, int characters = 0, double distanceFromTargetWords = 0, double distanceFromTargetCharacters = 0, int target = 0, int targetCharacters = 0})
const
SessionTotal.fromJson(Map<String, dynamic> json)
factory

Properties

characters int
final
distanceFromTargetCharacters double
final
distanceFromTargetWords double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target int
final
targetCharacters int
final
typeTarget String
final
words int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited