TargetGeneral class

Project-wide goal, reused by history/ to measure distance to the target.

Constructors

TargetGeneral({String typeTarget = '', int target = 0, int targetCharacters = 0, String? deadline, String genre = '', String subgenre = '', String audience = '', int targetWordCount = 0, int currentWordCount = 0, String language = ''})
const
TargetGeneral.fromJson(Map<String, dynamic> json)
factory

Properties

audience String
final
currentWordCount int
final
deadline String?
final
genre String
final
hashCode int
The hash code for this object.
no setterinherited
language String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subgenre String
final
target int
final
targetCharacters int
final
targetWordCount int
final
typeTarget String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited