WorldNode class

Constructors

WorldNode({String nodeId = '', String nodeName = '', double x = 0, double y = 0, double width = 0, double height = 0})
const
WorldNode.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
final
nodeId String
final
nodeName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
final
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited