IconRule class
The icon for a node type (in defaults) or for a single node id (in
overrides). variations maps an expression (exp:/state:, see the
format spec 9) to the icon name that replaces the base one when true.
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited